function T=plot_analysis(filename, fig, tid_labels, wrk_labels)
% plot_analysis(filename, fig, tid_labels, wrk_labels)
% show some of the information contained in profile data file
% PARAMS:
%           filename    a profiling data file name
%           fig         a number of first output figure, others will follow
%           tid_labels  a labels corresponding to task IDs
%           wrk_labels  a labels corresponding to workers (for each tid)

doPowerEstimation = 0; % not implemented yet
showBufferLoads = 0; % not implemented yet

f = fig;

close all

p_base = 2;

TASK_PROFILE_LEN = 14;   
TASK_ID               = 1;
TASK_START            = p_base + 0;  % timestamp, task start
TASK_ISSUED           = p_base + 1;  % task entered the priority queue
TASK_PQUEUE_WAITEND   = p_base + 2;  % end of pqueue waiting
TASK_SCHEDULER_START  = p_base + 3;  % task extracted from pqueue
TASK_SCHEDULER_FINISH = p_base + 4;  % leaving scheduler
TASK_BUFFER_ISSUED    = p_base + 5;  % inserted to buffer
TASK_BUFFER_WAITEND   = p_base + 6;  % picked up by accelerator thread
TASK_DATAIN           = p_base + 7;  % input data transmitted
TASK_CODEIN           = p_base + 8;  % code loaded
TASK_STARTED          = p_base + 9;  % task started o accelerator (start + parameters)
TASK_POLLING_START    = p_base + 10; % task polling start
TASK_PICOBLAZE_DONE   = p_base + 11; % finished picoblaze execution
TASK_DATAOUT          = p_base + 12; % data read out
TASK_DONE             = p_base + 13; % task done finished

PROCESSOR_ID          = p_base + 14;
BUFFER_OCCUPANCY      = p_base + 15;
PQUEUE_OCCUPANCY      = p_base + 16;

TASK_DATAIN_START      = p_base + 17;
TASK_CODEIN_START      = p_base + 18;
TASK_STATEIN_START     = p_base + 19;
TASK_DATAOUT_START     = p_base + 20;
TASK_STATEOUT_START    = p_base + 21;
TASK_STATEIN           = p_base + 22;
TASK_STATEOUT          = p_base + 23;

TASK_DBG_0             = p_base + 24;
TASK_DBG_1             = p_base + 25;
TASK_DBG_2             = p_base + 26;
TASK_DBG_3             = p_base + 27;
TASK_DBG_4             = p_base + 28;
TASK_DBG_5             = p_base + 29;
TASK_DBG_6             = p_base + 30;
TASK_DBG_7             = p_base + 31;
TASK_DBG_8             = p_base + 32;
TASK_DBG_9             = p_base + 33;
TASK_DBG_10            = p_base + 34;
TASK_DBG_11            = p_base + 35;
TASK_DBG_12            = p_base + 36;
TASK_DBG_13            = p_base + 37;

profile = load(filename);
%load -ASCII filename
all = [profile];


t_id = unique(profile(:, TASK_ID)); 

if (size(t_id,1) ~= size(tid_labels,1)) 
    disp('ERROR; the number of label rows must match with profile categories number');
    return
end

if (size(t_id,1) ~= size(wrk_labels,1)) 
    disp('ERROR; the number of label rows must match with worker labels');
    return
end

% statistics
disp(' ');      
disp('Average CLEAN task execution times');
disp('  ML506 @ 100MHz');
%disp('  workers: 1 x CMPLX, 1x FFT');
disp('  Values: datain, statein, codein, exec (of which polling), dataout, stateout');
for ii = 1:size(t_id,1)
    id = t_id(ii);
    
    p = profile(find(profile(:,1) == id), :);
    % diff times
    datain_time = p(:, TASK_DATAIN)-p(:, TASK_DATAIN_START);
    statein_time = p(:, TASK_STATEIN)-p(:, TASK_STATEIN_START);
    codein_time = p(:, TASK_CODEIN)-p(:, TASK_CODEIN_START);
    dataout_time = p(:, TASK_DATAOUT)-p(:, TASK_DATAOUT_START);
    stateout_time = p(:, TASK_STATEOUT)-p(:, TASK_STATEOUT_START);
    exec_time = p(:, TASK_PICOBLAZE_DONE)-p(:, TASK_STARTED);
    polling_time = p(:, TASK_PICOBLAZE_DONE)-p(:, TASK_POLLING_START);

    disp(['Mean  task ' char(tid_labels(ii)) ' times : ' ...
                num2str(round(mean(datain_time)),'%5u') ' ' ...
                num2str(round(mean(statein_time)),'%5u') ...
                ' ' num2str(round(mean(codein_time)),'%5u') ' ' ...
                num2str(round(mean(exec_time)),'%5u') ...
                '(' num2str(round(mean(polling_time)),'%5u') ')' ...
                ' ' num2str(round(mean(dataout_time)),'%5u') ' ' ...
                num2str(round(mean(stateout_time)),'%5u')]);

% JK kolacovy graf
if (0) 
    DataIn = round(mean(datain_time));
    StateIn = round(mean(statein_time));
    CodeIn = round(mean(codein_time));
    Exec = round(mean(exec_time));
%     Polling = round(mean(polling_time));
    DataOut = round(mean(dataout_time));
    StateOut = round(mean(stateout_time));
    
    x = [DataIn StateIn CodeIn Exec DataOut StateOut];
    figure(f); 
    f= f+1;
    pie(x, {'DataIn','StateIn','CodeIn','Exec','DataOut','StateOut'});
    colormap hsv    
    legend('DataIn','StateIn','CodeIn','Exec','DataOut','StateOut');
end
end

% gant chart for tasks
s = size(all);
p = profile(:,TASK_ID:PROCESSOR_ID);
alltimes = profile(:,TASK_START);
minTime = min(min(alltimes));
maxTime = max(max(alltimes));
p = sortrows(p,TASK_START);

diffTime = maxTime-minTime;

%priority_queue occupancy
allpQueue = [profile(:,TASK_SCHEDULER_START) profile(:,PQUEUE_OCCUPANCY)];
allpQueue = sortrows(allpQueue,1);

%accelerator buffer occupancy
allbuff = [profile(:,TASK_BUFFER_WAITEND) profile(:,BUFFER_OCCUPANCY) profile(:,PROCESSOR_ID)];
allbuff = sortrows(allbuff,3);

%gantt pro akceleratory
numbers = 1:size(profile,1);
allacc = [profile(:,TASK_ID:PQUEUE_OCCUPANCY) numbers'];
allacc = sortrows(allacc, PROCESSOR_ID);

% create category labels to profile
category = 1;
acc = allacc(1,PROCESSOR_ID);
for ii = 1:size(allacc,1)
    if (allacc(ii,PROCESSOR_ID) == acc)
        allacc(ii,PROCESSOR_ID) = category;
    else
        category = category + 1;
        acc = allacc(ii,PROCESSOR_ID);
        allacc(ii,PROCESSOR_ID) = category;
    end
end
numCategories = category;
allacc = sortrows(allacc,size(allacc,2));

% power values 
staticPower = 292.5;
cmplxBusyPower = 97.5;
cmplxIdlePower = 83.5;
cmplxOffPower = 0;
fftBusyPower = 82.5;
fftIdlePower = 57.5;
fftOffPower = 0;



p = allacc;

if (0)
figure(f), clf, hold on,
f = f+1;
title('RM processing of tasks');
ylim([0 size(p,1)])
p_frame = p;
fminTime = min(min(p_frame(:,TASK_START)));
p_frame(:,TASK_START:TASK_DONE) = p_frame(:,TASK_START:TASK_DONE) - fminTime;
fmaxTime = max(max(p_frame(:,TASK_DONE)));
xlim([0 fmaxTime])

xlabel('Time [\mus]')
ylabel('Task No. [-]')

for ii = 1:size(t_id,1)
    id= t_id(ii);
    switch(id) 
        case 1   
            plot([0 0],[0 0],'r-');
        case 2  
            plot([0 0],[0 0],'g-');
        case 3 
            plot([0 0],[0 0],'b-');
        case 4 
            plot([0 0],[0 0],'k-');
        case 5 
            plot([0 0],[0 0],'m-');
        otherwise 
            plot([0 0],[0 0],'m-');
            disp(['WARNING; using same color for tasks with ID = 5 and ID = ' num2str(ii)]);
    end 
end
legend(tid_labels,'Location','SouthEast');
    
for ii = 1:size(p_frame,1)
  switch(p_frame(ii,TASK_ID)) 
    case 1   
      plot([p_frame(ii,TASK_START) p_frame(ii,TASK_DONE)],[ii ii],'r-');
    case 2  
      plot([p_frame(ii,TASK_START) p_frame(ii,TASK_DONE)],[ii ii],'g-');
    case 3 
      plot([p_frame(ii,TASK_START) p_frame(ii,TASK_DONE)],[ii ii],'b-');
    case 4 
      plot([p_frame(ii,TASK_START) p_frame(ii,TASK_DONE)],[ii ii],'k-');
    case 5 
      plot([p_frame(ii,TASK_START) p_frame(ii,TASK_DONE)],[ii ii],'m-');
    otherwise 
      plot([p_frame(ii,TASK_START) p_frame(ii,TASK_DONE)],[ii ii],'m-');
  end 
end 
end    
   
if (0)    
figure(f), clf, hold on
f = f+1;
title('HW accelerator utilization (Gantt)');
xlim([0 fmaxTime])
ylim([0 numCategories+1])
xlabel('Time [\mus]')
ylabel('Processor No. [-]')
    
for ii = 1:size(t_id)
    id = t_id(ii);
    switch(id) 
        case 1   
            plot([0 0],[0 0],'r-');
        case 2  
            plot([0 0],[0 0],'g-');
        case 3 
            plot([0 0],[0 0],'b-');
        case 4 
            plot([0 0],[0 0],'k-');
        case 5 
            plot([0 0],[0 0],'m-');
        otherwise 
            plot([0 0],[0 0],'m-');
            disp(['WARNING; using same color for tasks with ID = 5 and ID = ' num2str(ii)]);
    end 
end

for ii = 1:size(p_frame,1)
    switch(p_frame(ii,TASK_ID))
        case 1 
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[p_frame(ii,PROCESSOR_ID) p_frame(ii,PROCESSOR_ID)],'rx-');
        case 2
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[p_frame(ii,PROCESSOR_ID) p_frame(ii,PROCESSOR_ID)],'gx-');
        case 3 
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[p_frame(ii,PROCESSOR_ID) p_frame(ii,PROCESSOR_ID)],'bx-');
        case 4 
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[p_frame(ii,PROCESSOR_ID) p_frame(ii,PROCESSOR_ID)],'kx-');
        case 5 
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[p_frame(ii,PROCESSOR_ID) p_frame(ii,PROCESSOR_ID)],'mx-');
        otherwise 
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[p_frame(ii,PROCESSOR_ID) p_frame(ii,PROCESSOR_ID)],'mx-');
    end 
end 
    
legend(tid_labels,'Location','SouthEast');   
end

%pQueue load, task buffer load
if (showBufferLoads)
    figure(f),  clf, hold on
    f = f+1;
    title('Priority Queue and Task Buffer loads (pozor vic pqueue jde do jednoho grafu !!!)');
    xlim([0 fmaxTime])
    xlabel('Time [\mus]')  
    ylabel('Buffered Task No. [-]')
    p_frame_s = sortrows(p_frame, TASK_SCHEDULER_START);
    plot(p_frame_s(:,TASK_SCHEDULER_START),p_frame_s(:,PQUEUE_OCCUPANCY),'r-')
           
    leg = ['pQueue       ';'Accelerator 1';'Accelerator 2';'Accelerator 3';'Accelerator 4';'Accelerator 5';'Others       '];
    for ii = 1:numCategories
        switch(ii)
            case 1
                col = 'g-';
            case 2
                col = 'b-';
            case 3
                col = 'c-';
            case 4
                col = 'm-';
            case 5
                col = 'k-';
            otherwise
                col = 'k-';
        end 
        cat = find(p_frame(:,PROCESSOR_ID) == ii);
        p_frame_cat = p_frame(cat,:);
        p_frame_cat_s = sortrows(p_frame_cat, TASK_BUFFER_WAITEND);
        plot(p_frame_cat_s(:,TASK_BUFFER_WAITEND),p_frame_cat_s(:,BUFFER_OCCUPANCY),col)
    end 
    legend(leg(1:numCategories+1,:));
end 

% evaluate task statistics
if (1) 
    disp(' ');      
    disp('Average task processing times by RM');
    disp('  ML506 @ 100MHz');
    disp('  workers: 1 x CMPLX, 1x FFT');
    disp('  Values: RM overhead, dataIO, Exec | Total ');

    for ii = 1:size(t_id,1)
        id = t_id(ii);
    
        prof = profile(find(profile(:, TASK_ID) == id), :);
        
        % times
        issue_time     = prof(:, TASK_ISSUED)          - prof(:, TASK_START);
        scheduler_time = prof(:, TASK_SCHEDULER_FINISH)- prof(:, TASK_SCHEDULER_START);
        statein_time   = prof(:, TASK_STATEIN)         - prof(:, TASK_STATEIN_START);
        datain_time    = prof(:, TASK_DATAIN)          - prof(:, TASK_DATAIN_START);
        codein_time    = prof(:, TASK_CODEIN)          - prof(:, TASK_CODEIN_START);
        exec_time      = prof(:, TASK_PICOBLAZE_DONE)  - prof(:, TASK_STARTED);
        polling_time   = prof(:, TASK_PICOBLAZE_DONE)  - prof(:, TASK_POLLING_START);
        stateout_time  = prof(:, TASK_STATEOUT)        - prof(:, TASK_STATEOUT_START);
        dataout_time   = prof(:, TASK_DATAOUT)         - prof(:, TASK_DATAOUT_START);
    
        RM_overhead = issue_time + scheduler_time;
        IO_time = statein_time + datain_time + codein_time + stateout_time + dataout_time;
        Exec_time = exec_time;
        Total = RM_overhead + IO_time + Exec_time;
    
        disp(['Mean values for ' char(tid_labels(ii)) ' : ' ...
             num2str(round(mean(RM_overhead))) ' ' ...
             num2str(round(mean(IO_time))) ' '...
             num2str(round(mean(Exec_time))) ' | ' ...
             num2str(round(mean(Total))) ...
             ]);
           
        if (0)
        figure(f), clf, hold on
        f = f+1;
        title(['Individual Accumulated Task Execution Times for task group ' tid_labels(ii)]);

        at = zeros(size(issue_time,1),5);
        at(:,1) = issue_time;
        at(:,2) = at(:,1) + scheduler_time;
        at(:,3) = at(:,2) + statein_time + datain_time + codein_time;
        at(:,4) = at(:,3) + exec_time;
        at(:,5) = at(:,4) + stateout_time + dataout_time;
        plot(at);  
       
        
        legend('GRM processing',...
               'Scheduler',...
               'Data Input',...
               'Execution',...
               'Data Output');        
        end   
    % HK kolacovy graf
    
        if (0) 
            x = [round(mean(RM_overhead)) ...
                 round(mean(statein_time + datain_time + codein_time)) ...
                 round(mean(exec_time)) ...
                 round(mean(stateout_time + dataout_time)) ...
                 ];
             if (ii == 1) 
                ax = x.*size(prof,1);
             else
                ax = ax+x.*size(prof,1);
             end;
            figure(f)
            clf
            %hold on; 
            f= f+1;
            %x = round(100*x./sum(x))
            pie(x, {'RM Overhead','Data Input','Execution','Data Output'});
            title(['Mean processing times for ' char(tid_labels(ii))]);
            %colormap hsv    
            %legend('RM Overhead','Data Input','Execution','Data Output');
        end           
    end 
        if (0)
            f= f+1;
            ax = round(100*ax./sum(ax));
            pie3(ax,[1 1 1 1], {['RM Overhead (' num2str(ax(1)) '%)'],['Data Input (' num2str(ax(2)) '%)'],['Execution (' num2str(ax(3)) '%)'],['Data Output (' num2str(ax(4)) '%)']});
            %title(['Weighted Average Task Processing Times']);
        end

end

if (0)
    % show data communication and execution gantt chart 
    for ii = 1:size(t_id,1)
        id = t_id(ii);
        
        
        prof = profile(find(profile(:, TASK_ID) == id), :);
        prof = sortrows(prof, TASK_START);
        
        no = 1:4;
        no2 = [];
        %check task numbers, eliminate tasks which do not exist
        for no_idx = 1:length(no)
            if (no(no_idx) <= size(prof,1))
                no2 = [no2 no(no_idx)];
            end
        end
        no = no2;
        
    
        fminTime = min(min(prof(no,TASK_START)));
        p_eframe = prof(no, TASK_ID:TASK_STATEOUT);
        p_eframe(:,TASK_START:TASK_DONE) = p_eframe(:,TASK_START:TASK_DONE) - fminTime;
        p_eframe(:,TASK_DATAIN_START:TASK_STATEOUT) = p_eframe(:,TASK_DATAIN_START:TASK_STATEOUT) - fminTime;
        fmaxTime = max(max(p_eframe(:,TASK_DONE)));

        %gantt pro akceleratory
        numbers = 1:size(p_eframe,1);
        np_eframe = [p_eframe numbers'];
        np_eframe = sortrows(np_eframe, PROCESSOR_ID);

        % create category labels to profile
        cat = 1;
        acc = np_eframe(1,PROCESSOR_ID);
        for iii = 1:size(np_eframe,1)
            if (np_eframe(iii,PROCESSOR_ID) == acc)
                np_eframe(iii,PROCESSOR_ID) = cat;
            else
                cat = cat + 1;
                acc = np_eframe(iii,PROCESSOR_ID);
                np_eframe(iii,PROCESSOR_ID) = cat;
            end
        end
        nCat = cat;
        p_eframe = sortrows(np_eframe, size(np_eframe,2));
    
        p_frame = p_eframe;
    
        

    
        % figure(f), clf, hold on 
        % f = f+1; 
        %plot(prof(no, TASK_START:TASK_DONE))
    
        figure(f), clf, hold on 
        f = f+1; 
        title(['Task processing Gantt, task: ' char(tid_labels(ii)) ' task No.: ' num2str(no)]);
        xlim([0 fmaxTime])
        ylim([0 numCategories+1])
        xlabel('Time [\mus]')
        ylabel('Processor No. [-]')
    

        plot([0 0],[0 0],'r-');
        plot([0 0],[0 0],'g-');
        plot([0 0],[0 0],'b-');
        plot([0 0],[0 0],'k-');
        plot([0 0],[0 0],'c-');
        plot([0 0],[0 0],'m-'); 

        plot([0 0],[0 0],'r-');
        plot([0 0],[0 0],'g-');
        plot([0 0],[0 0],'b-');
        plot([0 0],[0 0],'k-');
        plot([0 0],[0 0],'c-');
        plot([0 0],[0 0],'m-');
    
    
        tsk_sep = 0.01;
        for ii = 1:size(p_frame,1)
            % rm related things
            plot([p_frame(ii,TASK_START) p_frame(ii,TASK_ISSUED)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID) tsk_sep*ii+p_frame(ii,PROCESSOR_ID)],'r-');
            plot([p_frame(ii,TASK_ISSUED) p_frame(ii,TASK_PQUEUE_WAITEND)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.01 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.01],'g-');
            plot([p_frame(ii,TASK_PQUEUE_WAITEND) p_frame(ii,TASK_SCHEDULER_START)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.02 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.02],'b-');
            plot([p_frame(ii,TASK_SCHEDULER_START) p_frame(ii,TASK_SCHEDULER_FINISH)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.03 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.03],'k-');
            plot([p_frame(ii,TASK_SCHEDULER_FINISH) p_frame(ii,TASK_BUFFER_ISSUED)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.04 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.04],'c-');
            plot([p_frame(ii,TASK_BUFFER_ISSUED) p_frame(ii,TASK_BUFFER_WAITEND)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.05 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+0.05],'m-');
    
            % task data communication and execution
            plot([p_frame(ii,TASK_STATEIN_START) p_frame(ii,TASK_STATEIN)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.1 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.1],'r-');
            plot([p_frame(ii,TASK_DATAIN_START) p_frame(ii,TASK_DATAIN)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.2 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.2],'g-');
            plot([p_frame(ii,TASK_CODEIN_START) p_frame(ii,TASK_CODEIN)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.3 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.3],'b-');
            plot([p_frame(ii,TASK_STARTED) p_frame(ii,TASK_PICOBLAZE_DONE)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.4 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.4],'k-');
            plot([p_frame(ii,TASK_DATAOUT_START) p_frame(ii,TASK_DATAOUT)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.5 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.5],'c-');
            plot([p_frame(ii,TASK_STATEOUT_START) p_frame(ii,TASK_STATEOUT)],[tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.6 tsk_sep*ii+p_frame(ii,PROCESSOR_ID)+.6],'m-');
        end 
    
        legend('issue','pqueue','pqueue leave', 'scheduler', 'tbuffer issue', 'tbuffer', ...
                'State in','Data in','Code in','Execution','Data out','State out',...
                'Location','SouthEast');   
    end;
end


 prof = sortrows(profile, TASK_START);
        
 fminTime = min(min(prof(:,TASK_START)));
 p_eframe = prof(:, TASK_ID:TASK_STATEOUT);
 p_eframe(:,TASK_START:TASK_DONE) = p_eframe(:,TASK_START:TASK_DONE) - fminTime;
 p_eframe(:,TASK_DATAIN_START:TASK_STATEOUT) = p_eframe(:,TASK_DATAIN_START:TASK_STATEOUT) - fminTime;
 fmaxTime = max(max(p_eframe(:,TASK_DONE)));

 %gantt pro akceleratory
 numbers = 1:size(p_eframe,1);
 np_eframe = [p_eframe numbers'];
 np_eframe = sortrows(np_eframe, PROCESSOR_ID);

 % create category labels to profile
 cat = 1;
 acc = np_eframe(1,PROCESSOR_ID);
 for iii = 1:size(np_eframe,1)
     if (np_eframe(iii,PROCESSOR_ID) == acc)
                np_eframe(iii,PROCESSOR_ID) = cat;
            else
                cat = cat + 1;
                acc = np_eframe(iii,PROCESSOR_ID);
                np_eframe(iii,PROCESSOR_ID) = cat;
            end
        end
  nCat = cat;
  p_eframe = sortrows(np_eframe, size(np_eframe,2));
    
  p_frame = p_eframe;
 % T= p_frame(:,[TASK_STARTED TASK_PICOBLAZE_DONE TASK_ID PROCESSOR_ID]);
  T= p_frame(:,[TASK_STATEIN_START TASK_DONE TASK_ID PROCESSOR_ID]);


T(:,2)=T(:,2)-T(:,1);
T(:,1) = T(:,1)*10;
T(:,2) = T(:,2)*10;

if (0)
figure(f),f=f+1;
%h = GanttChart(T', {'';'';'';'';''},{'Cmplx';'FFT'},f);
h = GanttChart(T', {'';'';'';'';''},{'Cmplx';'Cmplx';'FFT';'Cmplx'},f);
xlabel('Time[ns]'), ylabel('Accelerator')
title('Schedule of Resource Manager Tasks');
legend(tid_labels,'location','East');
end
end
    
    




